class ScalarResolver:
    def resolve(self, value, root_node, trace):
        raise NotImplementedError